.. ricecooker documentation master file, created by
   sphinx-quickstart on Wed Sep 21 19:57:19 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ricecooker's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   README
   installation
   usage
   tutorial/index
   design
   nodes
   files
   exercises
   parsing_html
   modules
   history
   authors
   contributing

.. automodule:: ricecooker.classes



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
